@@ -1,7 +1,7 @@
 /* 
    Project: DataBasin
 
-   Copyright (C) 2008-2011 Free Software Foundation
+   Copyright (C) 2008-2012 Free Software Foundation
 
    Author: Riccardo Mottola
 
@@ -26,6 +26,7 @@
 
 #import "AppController.h"
 #import "DBSoap.h"
+#import "DBSoapCSV.h"
 #import "DBCVSWriter.h"
 #import "DBCVSReader.h"
 
@@ -64,6 +65,8 @@
 
 - (void)dealloc
 {
+  [dbCsv release];
+  [db release];
   [super dealloc];
 }
 
@@ -208,6 +211,8 @@
     password = [password stringByAppendingString:token];
     
   db = [[DBSoap alloc] init];
+  dbCsv = [[DBSoapCSV alloc] init];
+  [dbCsv setDBSoap:db];
   
   urlStr = nil;
   if ([popupEnvironment indexOfSelectedItem] == DB_ENVIRONMENT_PRODUCTION)
@@ -313,9 +318,15 @@
     }
   
   cvsWriter = [[DBCVSWriter alloc] initWithHandle:fileHandle];
-  
-  [db query :statement queryAll:([queryAllSelect state] == NSOnState) toWriter:cvsWriter];
-    
+  NS_DURING
+    [dbCsv query :statement queryAll:([queryAllSelect state] == NSOnState) toWriter:cvsWriter];
+  NS_HANDLER
+    if ([[localException name] hasPrefix:@"DB"])
+      {
+        [faultTextView setString:[localException reason]];
+        [faultPanel makeKeyAndOrderFront:nil];
+      }
+  NS_ENDHANDLER
   [cvsWriter release];
   [fileHandle closeFile];
 }
@@ -327,7 +338,16 @@
 {
   NSArray *objectNames;
 
-  objectNames = [db sObjectNames];
+  objectNames = nil;
+  NS_DURING
+    objectNames = [db sObjectNames];
+  NS_HANDLER
+    if ([[localException name] hasPrefix:@"DB"])
+      {
+        [faultTextView setString:[localException reason]];
+        [faultPanel makeKeyAndOrderFront:nil];
+      }
+  NS_ENDHANDLER
   [popupObjectsInsert removeAllItems];
   [popupObjectsInsert addItemsWithTitles: objectNames];
 
@@ -364,7 +384,7 @@
   reader = [[DBCVSReader alloc] initWithPath:filePath];
   
   NS_DURING
-    [db create:intoWhichObject fromReader:reader];
+    [dbCsv create:intoWhichObject fromReader:reader];
   NS_HANDLER
     if ([[localException name] hasPrefix:@"DB"])
       {
@@ -382,11 +402,11 @@
 
 - (IBAction)showUpdate:(id)sender
 {
-  NSArray      *objectsArray;
+  NSArray      *objectNames;
   
-  objectsArray  = nil;
+  objectNames  = nil;
   NS_DURING
-    objectsArray = [db describeGlobal];
+    objectNames = [db sObjectNames];
   NS_HANDLER
     if ([[localException name] hasPrefix:@"DB"])
       {
@@ -395,7 +415,7 @@
       }
   NS_ENDHANDLER
   [popupObjectsUpdate removeAllItems];
-  [popupObjectsUpdate addItemsWithTitles: objectsArray];
+  [popupObjectsUpdate addItemsWithTitles: objectNames];
     
   [winUpdate makeKeyAndOrderFront:self];
 }
@@ -430,7 +450,7 @@
   reader = [[DBCVSReader alloc] initWithPath:filePath];
   
   NS_DURING
-    [db update:whichObject fromReader:reader];
+    [dbCsv update:whichObject fromReader:reader];
   NS_HANDLER
     if ([[localException name] hasPrefix:@"DB"])
       {
@@ -488,6 +508,7 @@
   NSFileManager *fileManager;
   DBCVSWriter   *cvsWriter;
   DBCVSReader   *cvsReader;
+  int batchSize;
   
   statement = [fieldQuerySelectIdentify string];
   NSLog(@"%@", statement);
@@ -495,6 +516,26 @@
   NSLog(@"fpi: %@", filePathIn);
   filePathOut = [fieldFileSelectIdentifyOut stringValue];
   NSLog(@"fpo: %@", filePathOut);
+
+  batchSize = 0;
+  switch ([[popupBatchSizeIdentify selectedItem] tag])
+    {
+    case 1:
+      batchSize = 0;
+      break;
+    case 2:
+      batchSize = 10;
+      break;
+    case 3:
+      batchSize = 50;
+      break;
+    case 99:
+      batchSize = -1;
+      break;
+    default:
+      NSLog(@"unexpected batch size");
+    }
+  NSLog(@"batch Size: %d", batchSize);
   
   fileManager = [NSFileManager defaultManager];
 
@@ -517,7 +558,16 @@
 
   cvsWriter = [[DBCVSWriter alloc] initWithHandle:fileHandleOut];
 
-  [db queryIdentify :statement queryAll:([queryAllSelectIdentify state] == NSOnState) fromReader:cvsReader toWriter:cvsWriter];
+
+  NS_DURING
+    [dbCsv queryIdentify :statement queryAll:([queryAllSelectIdentify state] == NSOnState) fromReader:cvsReader toWriter:cvsWriter withBatchSize:batchSize];
+  NS_HANDLER
+    if ([[localException name] hasPrefix:@"DB"])
+      {
+        [faultTextView setString:[localException reason]];
+        [faultPanel makeKeyAndOrderFront:nil];
+      }
+  NS_ENDHANDLER
 
   [cvsReader release];
   
@@ -547,10 +597,10 @@
 
   if ([savePanel runModal] == NSOKButton)
     {
-    NSString *fileName;
+      NSString *fileName;
     
-    fileName = [savePanel filename];
-    [fieldFileDescribe setStringValue:fileName];
+      fileName = [savePanel filename];
+      [fieldFileDescribe setStringValue:fileName];
     }
 }
 
@@ -588,7 +638,7 @@
   NSLog(@"object: %@", whichObject);
   
   NS_DURING
-    [db describeSObject:whichObject toWriter:writer];
+    [dbCsv describeSObject:whichObject toWriter:writer];
   NS_HANDLER
     if ([[localException name] hasPrefix:@"DB"])
       {
@@ -698,7 +748,7 @@
   reader = [[DBCVSReader alloc] initWithPath:filePath byParsingHeaders:([checkSkipFirstLine state]==NSOnState)];  
   
   NS_DURING
-    [db deleteFromReader:reader];
+    [dbCsv deleteFromReader:reader];
   NS_HANDLER
     if ([[localException name] hasPrefix:@"DB"])
       {
