@@ -25,6 +25,10 @@
 
 #import <Foundation/Foundation.h>
 
+#if defined(__APPLE__) && (MAC_OS_X_VERSION_MAX_ALLOWED <= MAC_OS_X_VERSION_10_4)
+#define NSUInteger unsigned int
+#endif
+
 @interface DBCVSReader : NSObject
 {
   NSArray      *fieldNames;
