@@ -1,7 +1,7 @@
 /*
    Project: DataBasin
 
-   Copyright (C) 2008-2011 Free Software Foundation
+   Copyright (C) 2008-2012 Free Software Foundation
 
    Author: Riccardo Mottola
 
@@ -29,6 +29,7 @@
 #import "DBCVSReader.h"
 
 #define MAX_SOQL_SIZE 9000
+#define MAX_BATCH_SIZE 200
 
 @class DBSObject;
 
@@ -46,6 +47,9 @@
   NSArray  *sObjectList;
   /* list of all object names, custom and not */
   NSMutableArray  *sObjectNamesList;
+
+  /* create, update, upsert batch size */
+  unsigned upBatchSize;
 }
 
 - (void)login :(NSURL *)url :(NSString *)userName :(NSString *)password :(BOOL)useHttps;
@@ -53,18 +57,14 @@
 - (NSMutableArray *)queryFull :(NSString *)queryString queryAll:(BOOL)all;
 - (NSString *)query :(NSString *)queryString queryAll:(BOOL)all toArray:(NSMutableArray *)objects;
 - (NSString *)queryMore :(NSString *)locator toArray:(NSMutableArray *)objects;
-- (void)query :(NSString *)queryString queryAll:(BOOL)all toWriter:(DBCVSWriter *)writer;
-- (void)queryIdentify :(NSString *)queryString queryAll:(BOOL)all fromReader:(DBCVSReader *)reader toWriter:(DBCVSWriter *)writer;
-- (void)queryIdentify :(NSString *)queryString with: (NSString *)identifier queryAll:(BOOL)all fromArray:(NSArray *)fromArray toArray:(NSMutableArray *)outArray;
-- (void)create :(NSString *)objectName fromReader:(DBCVSReader *)reader;
-- (void)update :(NSString *)objectName fromReader:(DBCVSReader *)reader;
+- (void)queryIdentify :(NSString *)queryString with: (NSString *)identifier queryAll:(BOOL)all fromArray:(NSArray *)fromArray toArray:(NSMutableArray *)outArray withBatchSize:(int)batchSize;
+- (void)create :(NSString *)objectName fromArray:(NSMutableArray *)objects;
+- (void)update :(NSString *)objectName fromArray:(NSMutableArray *)objects;
 - (NSMutableArray *)delete :(NSArray *)objectIdArray;
-- (NSMutableArray *)deleteFromReader:(DBCVSReader *)reader;
 - (NSArray *)describeGlobal;
 - (NSArray *)sObjects;
 - (NSArray *)sObjectNames;
 - (void)updateObjects;
-- (void)describeSObject: (NSString *)objectType toWriter:(DBCVSWriter *)writer;
 - (DBSObject *)describeSObject: (NSString *)objectType;
 - (NSString *)identifyObjectById:(NSString *)sfId;
 
